@@ -1,7 +1,7 @@
 package Yars::Routes;
 
 # ABSTRACT: set up the routes for Yars.
-our $VERSION = '1.19'; # VERSION
+our $VERSION = '1.20'; # VERSION
 
 
 use strict;
@@ -34,7 +34,7 @@ BEGIN {
 }
 
 
-get '/' => sub { shift->render_text("welcome to Yars") } => 'index';
+get '/' => sub { shift->render(text => "welcome to Yars") } => 'index';
 
 
 get  '/file/#filename/:md5' => [ md5 => qr/[a-f0-9]{32}/ ] => \&_get;
@@ -464,7 +464,7 @@ get '/disk/usage' => sub {
         }
         $r{$disk}{count} = $c->tools->count_files($disk) if $count;
     }
-    return $c->render_json(\%r) unless $c->param('all');
+    return $c->render(autodata => \%r) unless $c->param('all');
     my %all = ( $c->tools->server_url => \%r );
     for my $server ($c->tools->server_urls) {
         next if exists $all{$server};
@@ -475,7 +475,7 @@ get '/disk/usage' => sub {
         };
         $all{$server} = $res->json;
     }
-    return $c->render_json(\%all);
+    return $c->render(autodata => \%all);
 };
 
 
@@ -491,7 +491,7 @@ post '/disk/status' => sub {
         }
         WARN "Sending ".$c->req->body;
         my $tx = $c->tools->_ua->post("$server/disk/status", $c->req->headers->to_hash, ''.$c->req->body );
-        return $c->render_text( $tx->success ? $tx->res->body : 'failed '.format_tx_error($tx->error) );
+        return $c->render( text => $tx->success ? $tx->res->body : 'failed '.format_tx_error($tx->error) );
     }
     $c->tools->disk_is_local($root) or return $c->render->exception("Disk $root is not on ".$c->tools->server_url);
     my $success;
@@ -499,7 +499,7 @@ post '/disk/status' => sub {
         /down/ and $success = $c->tools->mark_disk_down($root);
         /up/   and $success = $c->tools->mark_disk_up($root);
     }
-    $c->render_text($success ? "ok" : "failed" );
+    $c->render(text => $success ? "ok" : "failed" );
 };
 
 
@@ -578,7 +578,7 @@ post '/check/manifest' => sub {
     }
 
     $ret{found} = scalar @{ $ret{found} } unless $c->param("show_found");
-    $c->render_json(\%ret);
+    $c->render(autodata => \%ret);
 };
 
 
@@ -599,7 +599,7 @@ get '/servers/status' => sub {
             $all{$server} = "down";
         }
     }
-    $c->render_json(\%all);
+    $c->render(autodata => \%all);
 };
 
 
@@ -608,13 +608,13 @@ get '/server/status' => sub {
     my %disks =
       map { $_ => $c->tools->disk_is_up_verified($_) ? "up" : "down" }
       $c->tools->disk_roots;
-    $c->render_json(\%disks);
+    $c->render(autodata => \%disks);
 };
 
 
 get '/bucket_map' => sub {
     my $c = shift;
-    $c->render_json($c->tools->bucket_map)
+    $c->render(autodata => $c->tools->bucket_map)
 };
 
 
@@ -643,7 +643,7 @@ get '/bucket/usage' => sub {
         my @buckets = uniq map substr($_,0,$bucket_size), @dirs;
         $used{$disk} = \@buckets;
     }
-    $c->render_json({ used => \%used, assigned => \%assigned } );
+    $c->render(autodata => { used => \%used, assigned => \%assigned } );
 };
 
 
@@ -661,7 +661,7 @@ Yars::Routes - set up the routes for Yars.
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =head1 SYNOPSIS
 
